=================
django-analytical
=================

The django-analytical application integrates analytics services into a
Django_ project.

.. _Django: http://www.djangoproject.com/

:Package: http://pypi.python.org/pypi/django-analytical/
:Source:  http://github.com/jcassee/django-analytical


Overview
========

.. include:: ../README.rst
    :start-after: Django_ project.
    :end-before: Currently supported services:

To get a feel of how django-analytics works, check out the
:doc:`tutorial`.


Contents
========

.. toctree::
    :maxdepth: 2

    tutorial
    install
    features
    services
    settings
    history
    license
